<?php
/* ======================================================
 # www Redirect for Joomla! - v1.2.4 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v3.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: 
 # Support: support@web357.com
 # Last modified: Thursday 11 January 2024, 12:40:01 AM
 ========================================================= */

defined('_JEXEC') or die;

class plgSystemWWWRedirect extends JPlugin
{
	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);
	}

	public function onAfterInitialise()
	{
		// Get the application object.
		$app = JFactory::getApplication();

		// Do not enable the plugin at Joomla! backend
		if ($app->isClient('administrator'))
		{
			return;
		}

		// Do not enable the plugin at Localhost
		$exclude_list = array('127.0.0.1', '::1', 'localhost', 'yourdomain.com', 'www.yourdomain.com');
		if (in_array($_SERVER['SERVER_NAME'], $exclude_list)) 
		{
			return;
		}

		// Get Params from plugin
		$plugin 			= JPluginHelper::getPlugin( 'system', 'wwwredirect' );
		$params 			= new JRegistry($plugin->params); 
		$redirection_type 	= $params->get('redirection_type', 'with_www');
		$force_https 		= $params->get('force_https', 'with_https');

		// get URL
		$current_domain = $_SERVER['HTTP_HOST'];

		// get the http(s) var
		if ($force_https === 'with_https')
		{
			$http_s = "https";
		}
		elseif ($force_https === 'non_https')
		{
			$http_s = "http";
		}
		else
		{
			$http_s = isset($_SERVER['HTTPS']) ? "https" : "http";	
		}

		$current_url = $http_s . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";

		// Build the destination URL
		if ($redirection_type == 'with_www')
		{
			if (strpos($current_url, '//www.') === false) 
			{
				$destination_url = str_replace('//', '//www.', $current_url);
			}
		}
		else if ($redirection_type == 'non_www') 
		{
			if (strpos($current_url, '//www.') !== false) 
			{
				$destination_url = str_replace('//www.', '//', $current_url);
			}
		}

		// Build the final destination URL
		if (!empty($destination_url))
		{
			$final_destination_url = $destination_url;
		}
		else
		{
			$final_destination_url = $current_url;
		}

		// If the final destination URL is not the same with the current, then redirect to the final destination with www or non-www.
		$actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
		if ($actual_link !== $final_destination_url) 
		{
      		$this->redirectToTheFinalDestination($final_destination_url);
    	}
	}

	// Redirect URL
	public static function redirectToTheFinalDestination($final_destination_url)
	{
		if (!empty($final_destination_url))
		{
			header("HTTP/1.1 301 Moved Permanently");
			header('Location: ' . $final_destination_url);
			exit();
		}
	}
}